==========
Changelog
==========

This project adheres to `Semantic Versioning <https://semver.org/>`_.


{{ cookiecutter.version }} ({% now 'local' %})
---------------------------------------------

**Added**

* Created the project using mlf-core

**Fixed**

**Dependencies**

**Deprecated**
